==> haskell-threads-0.5.1.5-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-threads.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: threads
version: 0.5.1.5
id: threads-0.5.1.5-7F3M5SXcraK8ENw7FJnf4R
key: threads-0.5.1.5-7F3M5SXcraK8ENw7FJnf4R
license: BSD3
copyright: 2010–2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
stability: experimental
homepage: https://github.com/basvandijk/threads
synopsis: Fork threads and wait for their result
description:
    This package provides functions to fork threads and
    wait for their result, whether it'\''s an exception or a
    normal value.
    .
    Besides waiting for the termination of a single thread
    this packages also provides functions to wait for a
    group of threads to terminate.
    .
    This package is similar to the
    @threadmanager@, @async@ and @spawn@ packages.
    The advantages of this package are:
    .
    * Simpler API.
    .
    * More efficient in both space and time.
    .
    * No space-leak when forking a large number of threads.
    .
    * Correct handling of asynchronous exceptions.
    .
    * GHC specific functionality like @forkOn@ and @forkIOWithUnmask@.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Control.Concurrent.Thread Control.Concurrent.Thread.Group
hidden-modules: Control.Concurrent.Raw
abi: cd669669c8fcac07a2adc69fc266a958
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/threads-0.5.1.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/threads-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/threads-0.5.1.5
hs-libraries: HSthreads-0.5.1.5-7F3M5SXcraK8ENw7FJnf4R
depends:
    base-4.9.1.0 stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR
haddock-interfaces: /usr/share/doc/haskell-threads/html/threads.haddock
haddock-html: /usr/share/doc/haskell-threads/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-threads-0.5.1.5-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-threads.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: threads
version: 0.5.1.5
id: threads-0.5.1.5-9m9i8RnucibGDiptatWYP
key: threads-0.5.1.5-9m9i8RnucibGDiptatWYP
license: BSD3
copyright: 2010–2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
stability: experimental
homepage: https://github.com/basvandijk/threads
synopsis: Fork threads and wait for their result
description:
    This package provides functions to fork threads and
    wait for their result, whether it'\''s an exception or a
    normal value.
    .
    Besides waiting for the termination of a single thread
    this packages also provides functions to wait for a
    group of threads to terminate.
    .
    This package is similar to the
    @threadmanager@, @async@ and @spawn@ packages.
    The advantages of this package are:
    .
    * Simpler API.
    .
    * More efficient in both space and time.
    .
    * No space-leak when forking a large number of threads.
    .
    * Correct handling of asynchronous exceptions.
    .
    * GHC specific functionality like @forkOn@ and @forkIOWithUnmask@.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Thread Control.Concurrent.Thread.Group
hidden-modules: Control.Concurrent.Raw
abi: f8e98dd74cc75b9684076cba3985dfad
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/threads-0.5.1.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/threads-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/threads-0.5.1.5
hs-libraries: HSthreads-0.5.1.5-9m9i8RnucibGDiptatWYP
depends:
    base-4.10.0.0 stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=a88f5bbac4be96a38c5ca2a658c158a0
haddock-interfaces: /usr/share/doc/haskell-threads/html/threads.haddock
haddock-html: /usr/share/doc/haskell-threads/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
